powered by
Given a data name, this function returns the data frame
get_data_from_izmir(data_name)
A data frame that shows the observations for given data name
A data set name obtained from list_data_names()
#NOT RUN if (FALSE) { # It is just an example. get_data_from_izmir("asik-veysel-rekreasyon-alani-buz-pisti-kullanici-verileri") }
Run the code above in your browser using DataLab